summaryrefslogtreecommitdiffstats
path: root/kttsd/filters/xhtml2ssml/xmlelement.h
diff options
context:
space:
mode:
Diffstat (limited to 'kttsd/filters/xhtml2ssml/xmlelement.h')
-rw-r--r--kttsd/filters/xhtml2ssml/xmlelement.h34
1 files changed, 17 insertions, 17 deletions
diff --git a/kttsd/filters/xhtml2ssml/xmlelement.h b/kttsd/filters/xhtml2ssml/xmlelement.h
index c78cd6f..f3d8789 100644
--- a/kttsd/filters/xhtml2ssml/xmlelement.h
+++ b/kttsd/filters/xhtml2ssml/xmlelement.h
@@ -22,16 +22,16 @@
#ifndef XMLELEMENT_H
#define XMLELEMENT_H
-#include <qmap.h>
+#include <tqmap.h>
class QString;
-typedef QMap<QString, QString> AttributeToValueMap;
+typedef TQMap<TQString, TQString> AttributeToValueMap;
class XMLElement {
public:
XMLElement();
- XMLElement(const QString &name);
+ XMLElement(const TQString &name);
~XMLElement();
/// Copy constructor
@@ -42,11 +42,11 @@ public:
/// Get the name of the tag (the text between the greater than and less than symbols).
/// @returns the name of the tag.
- QString name();
+ TQString name();
/// set the name of the tag.
/// @param name the new name of the tag.
- void setName(const QString &name);
+ void setName(const TQString &name);
/// Get a textual representation of the starting of the tag with all attributes and their values set out.
/// @verbatim
@@ -55,35 +55,35 @@ public:
/// element.startTag(); <- <elem foo="bar">
/// @endverbatim
/// @returns A textual representation of the start of the element.
- QString startTag();
+ TQString startTag();
/// Get a textual representation of the closed tag that XMLElement represents.
/// @returns A textual representation of the closed tag represented by the XMLElement.
- QString endTag();
+ TQString endTag();
/// Create an attribute and set its value.
/// @param attr The attribute.
/// @param value The value of the attribute.
- void setAttribute(const QString &attr, const QString &value);
+ void setAttribute(const TQString &attr, const TQString &value);
/// Get the value of an attribute.
/// @param attr The attribute.
/// @returns The value of @param attr
- QString attribute(const QString &attr);
+ TQString attribute(const TQString &attr);
- /// Convert to a QString.
- /// Had issues with QMap and custom classes. For now you can just convert to/from QString and use
+ /// Convert to a TQString.
+ /// Had issues with TQMap and custom classes. For now you can just convert to/from TQString and use
/// That as the key/value pair.
- /// @returns A QString representation of the XMLAttribute.
- QString toQString();
+ /// @returns A TQString representation of the XMLAttribute.
+ TQString toQString();
- /// Create an XMLElement from a QString.
- /// @param str The QString to convert from. Must be of the following syntax- "foo name=\"bar\""
- static XMLElement fromQString(const QString &str);
+ /// Create an XMLElement from a TQString.
+ /// @param str The TQString to convert from. Must be of the following syntax- "foo name=\"bar\""
+ static XMLElement fromQString(const TQString &str);
private:
/// The name of the tag.
- QString m_name;
+ TQString m_name;
/// Attribute : value mappings.
AttributeToValueMap m_attrmapper;
};